summaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/llvmpipe/lp_bld_interp.h
diff options
context:
space:
mode:
authorJames Benton <[email protected]>2012-06-18 17:31:39 +0100
committerJosé Fonseca <[email protected]>2012-06-18 17:55:05 +0100
commitf34e2f484bb73bba79a5b3fa7cff2e79bc7f0cf9 (patch)
tree322eb51d897d002b28cf24dc0b5ca0dee8d0e783 /src/gallium/drivers/llvmpipe/lp_bld_interp.h
parentd1acae2bdca85a6cfdddbf8410271f9d7469a221 (diff)
llvmpipe: Implement cylindrical wrapping.
Tested against mesa demos cylwrap and dx9 DCT address.exe which now passes 100%. Signed-off-by: José Fonseca <[email protected]>
Diffstat (limited to 'src/gallium/drivers/llvmpipe/lp_bld_interp.h')
-rw-r--r--src/gallium/drivers/llvmpipe/lp_bld_interp.h8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/gallium/drivers/llvmpipe/lp_bld_interp.h b/src/gallium/drivers/llvmpipe/lp_bld_interp.h
index b0cbd9bdaec..6970a9b8c2c 100644
--- a/src/gallium/drivers/llvmpipe/lp_bld_interp.h
+++ b/src/gallium/drivers/llvmpipe/lp_bld_interp.h
@@ -67,9 +67,11 @@ enum lp_interp {
};
struct lp_shader_input {
- ushort interp:4; /* enum lp_interp */
- ushort usage_mask:4; /* bitmask of TGSI_WRITEMASK_x flags */
- ushort src_index:8; /* where to find values in incoming vertices */
+ uint interp:4; /* enum lp_interp */
+ uint usage_mask:4; /* bitmask of TGSI_WRITEMASK_x flags */
+ uint src_index:8; /* where to find values in incoming vertices */
+ uint cyl_wrap:4; /* TGSI_CYLINDRICAL_WRAP_x flags */
+ uint padding:12;
};